"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MockLambda = void 0;
const crypto_1 = require("crypto");
const request_1 = require("./request");
const utils_1 = require("./utils");
function MockLambda(opts) {
    const apiId = opts.apiId || (0, utils_1.randHex)(5);
    const accountId = opts.accountId || (0, utils_1.randHex)(8);
    const logStreamId = opts.logStreamId || (0, utils_1.randHex)(8);
    const region = opts.region || 'local';
    const functionName = opts.functionName || 'handler';
    const functionVersion = opts.functionVersion || '$LATEST';
    const routeKey = opts.routeKey || '$default';
    const stageName = opts.stageName || '$default';
    const domainName = opts.domainName || `${apiId}.execute-api.${region}.amazonaws.com`;
    const logGroupName = opts.logGroupName || `/aws/lambda/${functionName}`;
    const invokedFunctionArn = `arn:aws:lambda:${region}:${accountId}:function:${functionName}`;
    const memoryLimitInMB = opts.memoryLimitInMB || '1024';
    return {
        getEvent: getProxyEvent2,
        getContext: getContext
    };
    async function getProxyEvent2(req) {
        const { rawPath, rawQueryString, queryParams } = (0, request_1.getQuery)(req);
        const now = new Date();
        return {
            version: '2.0',
            routeKey: routeKey,
            rawPath: rawPath,
            rawQueryString: rawQueryString,
            headers: (0, request_1.getHeaders)(req),
            cookies: (0, request_1.getCookies)(req),
            queryStringParameters: queryParams,
            requestContext: {
                accountId: accountId,
                apiId: apiId,
                domainName: domainName,
                domainPrefix: apiId,
                http: {
                    method: req.method,
                    path: rawPath,
                    protocol: 'HTTP/1.1',
                    sourceIp: (0, request_1.getIp)(req),
                    userAgent: (0, request_1.getHeader)(req, 'User-Agent'),
                },
                requestId: (0, crypto_1.randomUUID)(),
                routeKey: routeKey,
                stage: stageName,
                time: (0, utils_1.toReqTime)(now),
                timeEpoch: now.getTime(),
            },
            body: await (0, request_1.getBody)(req),
            isBase64Encoded: false,
        };
    }
    function getContext() {
        const now = new Date();
        return {
            callbackWaitsForEmptyEventLoop: true,
            functionVersion: functionVersion,
            functionName: functionName,
            memoryLimitInMB: memoryLimitInMB,
            logGroupName: logGroupName,
            logStreamName: `${(0, utils_1.toStreamTime)(now)}/[${functionVersion}]${logStreamId}`,
            invokedFunctionArn: invokedFunctionArn,
            awsRequestId: (0, crypto_1.randomUUID)(),
            startedAt: now.getTime(),
            getRemainingTimeInMillis: () => 0,
            done: () => void 0,
            fail: () => void 0,
            succeed: () => void 0,
        };
    }
}
exports.MockLambda = MockLambda;
