"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const swc = require("@swc/core");
function SwcLoader() {
    return function (source, inputSourceMap) {
        const callback = this.async();
        const filename = this.resourcePath;
        let loaderOptions = (typeof this.getOptions === 'function'
            ? this.getOptions()
            : require('loader-utils').getOptions(this)) || {};
        if (Object.prototype.hasOwnProperty.call(loaderOptions, "sourceMap") &&
            !Object.prototype.hasOwnProperty.call(loaderOptions, "sourceMaps")) {
            loaderOptions = Object.assign({}, loaderOptions, {
                sourceMaps: loaderOptions.sourceMap,
            });
            delete loaderOptions.sourceMap;
        }
        if (inputSourceMap && typeof inputSourceMap === "object") {
            inputSourceMap = JSON.stringify(inputSourceMap);
        }
        const programmaticOptions = Object.assign({}, loaderOptions, {
            filename,
            inputSourceMap: inputSourceMap || undefined,
            sourceMaps: loaderOptions.sourceMaps === undefined ?
                this.sourceMap :
                loaderOptions.sourceMaps,
            sourceFileName: filename,
        });
        if (!programmaticOptions.inputSourceMap) {
            delete programmaticOptions.inputSourceMap;
        }
        const sync = programmaticOptions.sync;
        const parseMap = programmaticOptions.parseMap;
        delete programmaticOptions.sync;
        delete programmaticOptions.parseMap;
        delete programmaticOptions.customize;
        delete programmaticOptions.cacheDirectory;
        delete programmaticOptions.cacheIdentifier;
        delete programmaticOptions.cacheCompression;
        delete programmaticOptions.metadataSubscribers;
        if (this.mode && programmaticOptions.jsc && programmaticOptions.jsc.transform &&
            programmaticOptions.jsc.transform.react &&
            !Object.prototype.hasOwnProperty.call(programmaticOptions.jsc.transform.react, "development")) {
            programmaticOptions.jsc.transform.react.development = this.mode === 'development';
        }
        if (programmaticOptions.sourceMaps === "inline") {
            programmaticOptions.sourceMaps = true;
        }
        try {
            if (sync) {
                const output = swc.transformSync(source, programmaticOptions);
                callback(null, output.code, parseMap ? JSON.parse(output.map) : output.map);
            }
            else {
                swc.transform(source, programmaticOptions).then((output) => {
                    callback(null, output.code, parseMap ? JSON.parse(output.map) : output.map);
                }, (err) => {
                    callback(err);
                });
            }
        }
        catch (e) {
            callback(e);
        }
    };
}
module.exports = SwcLoader();
